@@ -10,6 +10,8 @@ from ordered_model.admin import OrderedModelAdmin
 from attributes.admin.forms import AttributeForm, AttributeOptionInline
 from attributes.models import Attribute
 
+from attributes.actions import categories_change_action
+
 
 def _get_attribute_admin_base_class():
 
@@ -38,8 +40,17 @@ class AttributeAdmin(OrderedModelAdmin, _get_attribute_admin_base_class()):
         ('type', 'slug', ),
     ]
 
-    def get_category_list(self, item):
-        return ', '.join([c.name for c in item.categories.all()])
+    actions = [categories_change_action]
+
+    def get_category_list(self, item, count=4):
+        categories = list(item.categories.all())
+
+        result = ', '.join([c.name for c in categories[:count]])
+
+        if len(categories) > count:
+            result += ' (+{})'.format(len(categories) - count)
+
+        return result
 
     get_category_list.short_description = _('Categories')
 
