@@ -2,7 +2,6 @@
 import six
 
 from django.db import models
-from django.conf import settings
 from django.utils.translation import ugettext_lazy as _
 
 from attributes.managers import AttributeValueManager
@@ -42,7 +41,7 @@ class AttributeValue(models.Model):
         on_delete=models.CASCADE)
 
     entry = models.ForeignKey(
-        settings.ATTRIBUTES_ENTRY_MODEL,
+        'products.Product',
         related_name='attr_values',
         on_delete=models.CASCADE)
 
